@@ -34,8 +34,8 @@ class CumulocityView(RelatedView):
             obj_serializer,
             data=None,
             need_results=False,
-            related_obj: list = None,
-            m_to_m_obj: list = None,
+            related_objs: list = None,
+            m_to_m_objs: list = None,
             related_mapping=None,
             m_to_m_mapping=None,
             **kwargs,
@@ -52,12 +52,12 @@ class CumulocityView(RelatedView):
                 if not success:
                     return RESTResponse(results)
                 serializer = obj_serializer(data=data)
-                if not related_obj:
-                    related_obj, related_mapping = self.injection_data.related_data("POST")
-                if not m_to_m_obj:
-                    m_to_m_obj, m_to_m_mapping = self.injection_data.m_to_m_data("POST")
-                self.relate.execute_related_extend(related_obj, related_mapping, data)
-                self.relate.execute_m_to_m_extend(m_to_m_obj, m_to_m_mapping, data)
+                if not related_objs:
+                    related_objs, related_mapping = self.injection_data.related_data("POST")
+                if not m_to_m_objs:
+                    m_to_m_objs, m_to_m_mapping = self.injection_data.m_to_m_data("POST")
+                self.relate.execute_related_extend(related_objs, related_mapping, data)
+                self.relate.execute_m_to_m_extend(m_to_m_objs, m_to_m_mapping, data)
                 try:
                     valid = serializer.is_valid(raise_exception=True)
                     serializer.save()
@@ -65,7 +65,7 @@ class CumulocityView(RelatedView):
                     results.code = 200
                 except Exception as e:
                     results.code, results.describe = get_error_status_code(e)
-                self.syn.post(request, results)
+                self.syn.post(request, results,data)
         except SynchronousError as e:
             pass
         except Exception as e:
