@@ -38,16 +38,16 @@ class BaseView(APIView, Select, BaseORM):
     """
 
     def get(
-        self,
-        request,
-        obj,
-        obj_serializer,
-        *,
-        extend_conditions: dict = None,
-        need_results=False,
-        need_queryset=False,
-        keys=None,
-        **kwargs,
+            self,
+            request,
+            obj,
+            obj_serializer,
+            *,
+            extend_conditions: dict = None,
+            need_results=False,
+            need_queryset=False,
+            keys=None,
+            **kwargs,
     ):
         """
         根据键值对查找数据
@@ -68,15 +68,10 @@ class BaseView(APIView, Select, BaseORM):
             return results, queryset
         return RESTResponse(results)
 
-    def post(self, request, obj, obj_serializer, *, data=None, need_results=False, **kwargs):
+    def post(self, request, obj, obj_serializer, *, data=None, need_results=False, raise_exception=False, **kwargs):
         """
         添加数据
-        :param request:
-        :param obj:
-        :param obj_serializer:
-        :param data:
-        :param need_results:
-        :return:
+
         """
         results = Results()
         if not data:
@@ -88,6 +83,8 @@ class BaseView(APIView, Select, BaseORM):
             valid = serializer.is_valid(raise_exception=True)
             serializer.save()
         except Exception as e:
+            if raise_exception:
+                raise e
             results.code, results.describe = get_error_status_code(e)
         else:
             results.describe = "add  successfully！！！"
@@ -98,17 +95,18 @@ class BaseView(APIView, Select, BaseORM):
         return RESTResponse(results)
 
     def put(
-        self,
-        request,
-        obj,
-        obj_serializer,
-        *,
-        data=None,
-        pk="id",
-        extend_conditions: dict = None,
-        need_results=False,
-        need_queryset=False,
-        **kwargs,
+            self,
+            request,
+            obj,
+            obj_serializer,
+            *,
+            data=None,
+            pk="id",
+            extend_conditions: dict = None,
+            need_results=False,
+            need_queryset=False,
+            raise_exception=False,
+            **kwargs,
     ):
         instance = None
         results = Results()
@@ -140,6 +138,8 @@ class BaseView(APIView, Select, BaseORM):
                     instance._prefetched_objects_cache = {}
 
         except Exception as e:
+            if raise_exception:
+                raise e
             results.code, results.describe = get_error_status_code(e)
 
         if need_results:
@@ -149,17 +149,18 @@ class BaseView(APIView, Select, BaseORM):
         return RESTResponse(results)
 
     def delete(
-        self,
-        request,
-        obj,
-        obj_serializer,
-        *,
-        data=None,
-        pk="id",
-        extend_conditions: dict = None,
-        need_results=False,
-        need_queryset=False,
-        **kwargs,
+            self,
+            request,
+            obj,
+            obj_serializer,
+            *,
+            data=None,
+            pk="id",
+            extend_conditions: dict = None,
+            need_results=False,
+            need_queryset=False,
+            raise_exception=False,
+            **kwargs,
     ):
         instance = None
         results = Results()
@@ -180,6 +181,8 @@ class BaseView(APIView, Select, BaseORM):
                 results.describe = "deleted successfully！！！"
                 results.status = SUCCESS
         except Exception as e:
+            if raise_exception:
+                raise e
             results.code, results.describe = get_error_status_code(e)
 
         if need_results:
